@@ -2,9 +2,13 @@ from typing import Optional, Any
 from mypy_extensions import TypedDict
 
 from flask.json import dumps
+from flask import current_app
 from werkzeug import Response
 
 RESP_MSGS = {
+    200: 'ok',
+
+    400: 'failed',
     401: '未登录',
     403: '未授权',
     404: '不正确的链接地址',
@@ -20,7 +24,7 @@ class RespType(TypedDict):
     detail: Any
 
 
-def gen_response(code: int, message: str = '', detail: Optional[str] = None,
+def gen_response(code: int, message: str = None, detail: Optional[str] = None,
                  data=None) -> RespType:
     """Func for generate response body.
 
@@ -34,10 +38,27 @@ def gen_response(code: int, message: str = '', detail: Optional[str] = None,
     Returns:
         dict: A dict contains all args.
 
+    2021-07-08 Updated:
+        Default type of `code` in response is force conversion to `str`, now
+        support set `HOBBIT_USE_CODE_ORIGIN_TYPE = True` to return origin type.
+
+    2021-07-13 Updated:
+        Support set `HOBBIT_RESPONSE_MESSAGE_MAPS` to use self-defined
+        response message. `HOBBIT_RESPONSE_MESSAGE_MAPS` must be dict.
     """
+    use_origin_type = current_app.config.get(
+        'HOBBIT_USE_CODE_ORIGIN_TYPE', False)
+
+    resp_msgs = current_app.config.get('HOBBIT_RESPONSE_MESSAGE_MAPS', {})
+    assert isinstance(resp_msgs, dict), \
+        'HOBBIT_RESPONSE_MESSAGE_MAPS must be dict type.'
+    if not message:
+        message = resp_msgs.get(code)
+        if message is None:
+            message = RESP_MSGS.get(code, 'unknown')
     return {
-        'code': str(code),
-        'message': message or RESP_MSGS.get(code, '未知错误'),  # type: ignore
+        'code': str(code) if use_origin_type is False else code,
+        'message': message,  # type: ignore
         'data': data,
         'detail': detail,
     }
@@ -56,7 +77,8 @@ class Result(Response):
             'Error response, must include keys: code, data, detail, message'
         super(Result, self).__init__(
             response=dumps(response, indent=0, separators=(',', ':')) + '\n',
-            status=status or self.status, headers=headers, mimetype=mimetype,
+            status=status if status is not None else self.status,
+            headers=headers, mimetype=mimetype,
             content_type=content_type, direct_passthrough=direct_passthrough)
 
 
@@ -68,7 +90,8 @@ class SuccessResult(Result):
     def __init__(self, message: str = '', code: Optional[int] = None,
                  detail: Any = None, status: Optional[int] = None, data=None):
         super(SuccessResult, self).__init__(
-            gen_response(code or self.status, message, detail, data),
+            gen_response(code if code is not None else self.status,
+                         message, detail, data),
             status or self.status)
 
 
@@ -80,7 +103,9 @@ class FailedResult(Result):
     def __init__(self, message: str = '', code: Optional[int] = None,
                  detail: Any = None):
         super(FailedResult, self).__init__(
-            gen_response(code or self.status, message, detail), self.status)
+            gen_response(
+                code if code is not None else self.status, message, detail),
+            self.status)
 
 
 class UnauthorizedResult(FailedResult):
